# fateslist.py

fateslist.py is a API wrapper/library around [Fates List](https://fateslist.xyz), which is a great novel bot list featuring over hundreds of bots for our users owned by ``Rootspring#6701``. See [here](https://py.fateslist.xyz) for docs

## Issues And Contributing

This API wrapper/library is maintained by ``Rootspring#6701``. If you wish to contribute to this project or report an issue, please make a Github Issue or a Pull Request (templates coming soon)
